@@ -5,7 +5,7 @@ fn main() {
     tracing_subscriber::fmt::init();
 
     if let Err(e) = run() {
-        error!("{}", e);
+        error!("{:?}", e);
         std::process::exit(1);
     }
 }
